#!/usr/bin/python
# re-interpret gtest based tests to create TET output
# 07/15/09 Stew Benedict <stewb@linuxfoundation.org>
# 08/21/09 Wei Zhang <wei.z.zhang@intel.com> 
#  merge journals to one

# Copyright (c) 2007-2009, Linux Foundation
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:

#    * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#    * Neither the name of the Linux Foundation nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import sys
import os
import string
import subprocess
sys.path.append(sys.path[0] + '/../share')
import tetj
version = '0.2'

# shell executor, return [exitcode, stdout and stderr]
def shell_exec3(cmd):
    pingPopen = subprocess.Popen(args=cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    exit_code = pingPopen.wait()
    p = pingPopen.stdout.read() + pingPopen.stderr.read()
    return [exit_code, p.strip('\n')]


def main(argv):
    if len(argv) == 1  or '-?' in argv or '-h' in argv:
        print 'Usage: ' + argv[0] + ' [-j] <test name>'
        sys.exit(1)

    # expecting a test program name here
    prog_ndx_start = 1
    do_journal = 0
    tcount = 0
 
    if '-j' in argv:
        do_journal = 1
        prog_ndx_start = string.index(argv, "-j") + 1

    fullargs = string.join(argv, ' ')

    # prep the journal header
    if do_journal:
        myname = os.path.basename(argv[0])
        journal = tetj.Journal('journal.' + 'all', "[ignore]")
        journal.add_config("VSX_NAME=gtester-to-tet-1.py " + version + " (noarch)")
        journal.config_end()

    for prog_ndx in range(prog_ndx_start, len(argv)):
        testapp = argv[prog_ndx]
        jsuffix = os.path.basename(testapp)

        # see if we can access the file
        try:
            f = file(testapp, 'r')
        except:
            print 'Failed to open ' + testapp
            sys.exit(1)
        f.close

	precwd = os.getcwd()
	os.chdir (os.path.dirname(testapp))
        # run the test and process the results
	list = shell_exec3 ("./%s -l" %jsuffix)
	if 0 != list[0]:
	    print "testapp \'%s\' failed on parameter -l" %testapp
	else:
            testlist = list[1].split('\n')
            testcount = str(len(testlist))
            if do_journal:
                journal.scenario_info('"total tests in ' + testapp + " " + testcount + '"')

	    for testname in testlist:
		showname = testname.replace('/', '')
            	cleanname = showname.replace(' ', '')
		testresult = shell_exec3 ("./%s -p \"%s\"" %(jsuffix, testname))
		if 0 == testresult[0]:
            	    print '\n\033[33m%-60s\033[32m[PASS]\033[0m\n' % (testname)
		else:
            	    print '\n\033[33m%-60s\033[31m[FAIL]\033[0m\n' % (testname)
		print testresult[1] + '\n'

                if do_journal:
                    journal.testcase_start(cleanname)
                    journal.purpose_start(showname)
            	    journal.testcase_info(0, 0, 0, testresult[1])
                    if 0 == testresult[0]:
                        journal.result(tetj.TETJ_PASS)
                    else:    
                        journal.result(tetj.TETJ_FAIL)

                if do_journal:
                    journal.purpose_end()
                    journal.testcase_end()
	
	os.chdir (precwd)

    if do_journal:
        journal.close()

if __name__=='__main__':
    main(sys.argv)

